0.9.9 API documentation: quaternion_float_precision.hpp File Reference

| 0.9.9 API documentation

- Main Page
- Modules
- Files

- File List

Typedefs
quaternion_float_precision.hpp File Reference

GLM_EXT_quaternion_float_precision More...

Go to the source code of this file.

## Typedefs
typedef qua< float, highp > | highp_quat
| Quaternion of single-precision floating-point numbers using high precision arithmetic in term of ULPs.
typedef qua< float, lowp > | lowp_quat
| Quaternion of single-precision floating-point numbers using high precision arithmetic in term of ULPs.
typedef qua< float, mediump > | mediump_quat
| Quaternion of single-precision floating-point numbers using high precision arithmetic in term of ULPs.

## Detailed Description

GLM_EXT_quaternion_float_precision

Definition in file quaternion_float_precision.hpp.